@@ -14,6 +14,7 @@ pimplot <-
            fontface = "italic", 
            fontsize = 3,
            crisp = FALSE,
+           consH = FALSE,
            ...)
   { 
     dots <- list(...)
@@ -53,6 +54,7 @@ pimplot <-
                 xy.plot(P[,i, drop=FALSE], 'out', data = P, xlab=paste("Row ", colnames(P)[i]), ylab=outcome, main="Sufficiency Plot",
                             labcol=labcol, 
                             jitter = jitter,
+                            consH = consH,
                             font = font,
                             fontface = fontface, 
                             fontsize = fontsize, 
@@ -63,6 +65,7 @@ pimplot <-
               else {xy.plot(P[,i, drop=FALSE], 'out', data = P, xlab=paste("Row ", colnames(P)[i]), ylab=paste("~",outcome), main="Sufficiency Plot",
                                 labcol=labcol, 
                                 jitter = jitter,
+                                consH = consH,
                                 font = font,
                                 fontface = fontface, 
                                 fontsize = fontsize, 
@@ -99,6 +102,7 @@ pimplot <-
               xy.plot(P[,i, drop=FALSE], "out", data = P, xlab=colnames(P[i]), ylab=outcome, main="Sufficiency Plot",
                 labcol=labcol, 
                 jitter = jitter,
+                consH = consH,
                 font = font,
                 fontface = fontface, 
                 fontsize = fontsize, 
@@ -109,6 +113,7 @@ pimplot <-
               else {xy.plot(P[,i, drop=FALSE], 'out', data = P, xlab=colnames(P)[i], ylab=paste("~",outcome), main="Sufficiency Plot",
                                 labcol=labcol, 
                                 jitter = jitter,
+                                consH = consH,
                                 font = font,
                                 fontface = fontface, 
                                 fontsize = fontsize, 
@@ -147,6 +152,7 @@ pimplot <-
               xy.plot(P[,i, drop=FALSE], 'out', data = P, xlab=paste("Row ", colnames(P)[i]), ylab=outcome, main="Sufficiency Plot",
                           labcol=labcol, 
                           jitter = jitter,
+                          consH = consH,
                           font = font,
                           fontface = fontface, 
                           fontsize = fontsize, 
@@ -157,6 +163,7 @@ pimplot <-
               else {xy.plot(P[,i, drop=FALSE], 'out', data = P, xlab=paste("Row ", colnames(P)[i]), ylab=paste("~",outcome), main="Sufficiency Plot",
                                 labcol=labcol, 
                                 jitter = jitter,
+                                consH = consH,
                                 font = font,
                                 fontface = fontface, 
                                 fontsize = fontsize, 
@@ -195,6 +202,7 @@ pimplot <-
                       labcol=labcol, 
                       jitter = jitter,
                       font = font,
+                      consH = consH,
                       fontface = fontface, 
                       fontsize = fontsize, 
                       labs = fil,
@@ -206,6 +214,7 @@ pimplot <-
                             labcol=labcol, 
                             jitter = jitter,
                             font = font,
+                            consH = consH,
                             fontface = fontface, 
                             fontsize = fontsize, 
                             labs = fil,
